==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>A verificação está quase concluída</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Verificado alguns erros</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Ir para a área de trabalho</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Bem-vindo de volta, o seu sistema foi atualizado com sucesso</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Versão atual:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Exibir logs</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Atualizações bem-sucedidas</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Seu computador será reiniciado em breve %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Seu computador será desligado em breve %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>O processo de reinicialização automática falhou. Tente reiniciar manualmente.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>O processo de desligamento automático falhou. Tente desligar manualmente.</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Ocultar logs</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>A atualização falhou</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erro desconhecido</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>O backup falhou</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Impossível executar o backup do sistema. Se você continuar com as atualizações, não poderá reverter o sistema para uma versão anterior.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Espaço insuficiente em disco. Limpe o disco e tente novamente.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Falha ao conectar-se aos serviços de backup. Verifique e tente novamente.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Falha ao conectar-se aos serviços de atualização. Verifique e tente novamente.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Erro de dependência</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Erro do DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Fazer backup novamente</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abortar</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Continuar para atualizar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Ir para a área de trabalho</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Preparando para atualizar...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>O desligamento forçado ou a tentativa de desligá-lo durante a instalação de atualizações, poderá danificar o sistema.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.24.tar.xz: BUILD/src/dde-update/translations/dde-update_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>A verificação está quase concluída</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Verificado alguns erros</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Ir para a área de trabalho</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Bem-vindo de volta, o seu sistema foi atualizado com sucesso</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Versão atual:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Atualizações bem-sucedidas</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Seu computador será reiniciado em breve %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Seu computador será desligado em breve %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>O processo de reinicialização automática falhou. Tente reiniciar manualmente.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>O processo de desligamento automático falhou. Tente desligar manualmente.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Exibir logs de atualização</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Recolher logs de atualização</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>O log foi exportado para a área de trabalho</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>A exportação do log falhou, tente novamente</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>A atualização falhou</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erro desconhecido</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>O backup falhou</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Impossível executar o backup do sistema. Se você continuar com as atualizações, não poderá reverter o sistema para uma versão anterior.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Espaço insuficiente em disco. Limpe o disco e tente novamente.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Falha ao conectar-se aos serviços de backup. Verifique e tente novamente.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Falha ao conectar-se aos serviços de atualização. Verifique e tente novamente.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Erro de dependência</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Erro do DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Fazer backup novamente</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abortar</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Continuar para atualizar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Ir para a área de trabalho</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Preparando para atualizar...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>O desligamento forçado ou a tentativa de desligá-lo durante a instalação de atualizações, poderá danificar o sistema.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Exibir logs de atualização</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Recolher logs de atualização</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>updatelog</translation>
    </message>
</context>
</TS>
